'use client'
import React, { useState, useEffect, useMemo, useCallback } from "react";
import CallBtn from '../CallBtn';
import axios from "@/services/APIservices";

const CarouselItem = React.memo(() => {
  const [displayPosts, setDisplayPosts] = useState([]);
  const [error, setError] = useState(null);

  console.log("CarouselItem rendered"); // Debugging render count

  const fetchAdminPosts = useCallback(async () => {
    try {
      const response = await axios.get('api/admin-data');
      if (response.data.success) {
        const allPosts = response.data.data.flatMap(admin => 
          (admin.post_details || []).map(post => ({
            ...post,
            adminName: admin.name,
            adminProfile: admin.profile_photo,
            role: admin.role  // Fetching role information 
          }))
        );
        setDisplayPosts((prev) => (prev.length ? prev : allPosts.slice(0, 3))); // Prevent overwriting
      } else {
        setError('Failed to load posts');
      }
    } catch (error) {
      console.error('Error fetching admin posts:', error);
      setError('Failed to load posts');
    }
  }, []);

  useEffect(() => {
    fetchAdminPosts(); // Only runs once because `fetchAdminPosts` is memoized
  }, [fetchAdminPosts]);

  const formatPrice = (price) => {
    return new Intl.NumberFormat('en-IN', {
      style: 'currency',
      currency: 'INR',
      maximumFractionDigits: 0
    }).format(price).replace('₹', '₹ ');
  };

  if (!displayPosts.length && !error) {
    return (
      <div className="flex justify-center items-center min-h-[200px]">
        <div className="animate-spin rounded-full h-12 w-12 border-t-2 border-b-2 border-brand"></div>
      </div>
    );
  }

  if (error) {
    return (
      <div className="text-center text-red-500 p-4">
        {error}
      </div>
    );
  }

  return (
    <>
      {displayPosts.map((post) => {
        const properties = [
          {
            image: "/icons/land-size.png",
            title: "Land Size",
            value: `${post.land_size || '2500 sqyrd'} ${post.land_size_unit}`
          },
          {
            image: "/icons/land-type.png",
            title: "Land Type",
            value: post.land_type || "Residential" 
          },
          {
            image: "/icons/dimension.png",
            title: "Dimension (L*B)",
            value: post.dimension || "null"
          }
        ];

        return (
          <div key={post.id} className='p-2 flex lg:flex-row flex-col gap-2 items-center bg-white rounded-lg mb-4'>
            <img 
              src={post.land_photos?.[0]?.url || "/buyland.png"} 
              alt={post.title || "Land Image"} 
              className='lg:h-full h-[211px] w-full object-cover lg:w-auto' 
            />
            <div className='flex flex-col gap-2'>
              <div>
                <span className='font-semibold'>
                  {formatPrice(post.location_details?.land_prices?.[0]?.price || 6500586)}
                </span>
                <span className='text-tertiary text-sm'> Per SQ Feet</span>
              </div>
              
              <p>{post.land_type || "Residential Land "} Land</p>
              <p className='text-tertiary text-sm'>Posted by {post.role || 'Agent'}</p>
              
              <div className='bg-[#d9d9d9] w-fit lg:pe-4 lg:ps-3 py-2 text-sm flex gap-2 rounded-lg'>
                {properties.map((item, index) => (
                  <div 
                    className={`flex gap-1 px-1 ${index !== 0 && "border-black lg:border-l-[1px]"} whitespace-nowrap text-xs items-center`} 
                    key={item.title}
                  >
                    <img src={item.image} alt="" />
                    <div>
                      <p className='text-xs lg:text-sm'>{item.title}</p>
                      <p className='font-semibold text-xs lg:text-sm'>{item.value}</p>
                    </div>
                  </div>
                ))}
              </div>

              <div className="flex lg:gap-4 gap-2 text-xs lg:flex-row flex-col">
                <p className='font-semibold text-tertiary underline'>
                  {post.location_details.plot_facing || "Location not specified"}
                </p>
                
              </div>

              <div className="flex lg:flex-row flex-col items-center mt-2 lg:gap-16 whitespace-nowrap gap-4">
                <div className="flex gap-2 items-center">
                  <img 
                    src={post.adminProfile || "/profile.png"} 
                    alt={post.adminName} 
                    className='w-[43px]' 
                  />
                  <p className='font-semibold'>{post.adminName || "Suraj Pandey"}</p>
                </div>
                <div className="flex gap-4 text-sm font-semibold">
                  <button className='flex items-center text-brand border-brand border-[1px] rounded-lg gap-2 px-4 py-1'>
                    <img src="/icons/tabler_click.png" alt="" className='w-6' />
                    <p>Know More</p>
                  </button>
                  <CallBtn title={"Contact Seller"} />
                </div>
              </div>
            </div>
          </div>
        );
      })}
    </>
  );
});

export default CarouselItem;